( cd opt/kde/lib ; rm -rf libaudiofile.so )
( cd opt/kde/lib ; ln -sf libaudiofile.so.0.0.0 libaudiofile.so )
( cd opt/kde/lib ; rm -rf libaudiofile.so.0 )
( cd opt/kde/lib ; ln -sf libaudiofile.so.0.0.0 libaudiofile.so.0 )
( cd opt/kde/lib ; rm -rf libmimelib.so )
( cd opt/kde/lib ; ln -sf libmimelib.so.1.0.1 libmimelib.so )
( cd opt/kde/lib ; rm -rf libmimelib.so.1 )
( cd opt/kde/lib ; ln -sf libmimelib.so.1.0.1 libmimelib.so.1 )
